"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheStore = exports.StoreKey = void 0;
exports.StoreKey = {
    Config: 'dvc:config',
    User: 'dvc:user',
    AnonUserId: 'dvc:anonymous_user_id',
    AnonymousConfig: 'dvc:anonymous_config',
    IdentifiedConfig: 'dvc:identified_config',
};
var CacheStore = /** @class */ (function () {
    function CacheStore(localStorage, logger) {
        this.store = localStorage;
        this.logger = logger;
    }
    CacheStore.prototype.save = function (storeKey, data) {
        var _a;
        (_a = this.store) === null || _a === void 0 ? void 0 : _a.setItem(storeKey, JSON.stringify(data));
    };
    CacheStore.prototype.load = function (storeKey) {
        var _a;
        var item = (_a = this.store) === null || _a === void 0 ? void 0 : _a.getItem(storeKey);
        return item ? JSON.parse(item) : null;
    };
    CacheStore.prototype.getConfigKey = function (user) {
        return user.isAnonymous ? exports.StoreKey.AnonymousConfig : exports.StoreKey.IdentifiedConfig;
    };
    CacheStore.prototype.getConfigUserIdKey = function (user) {
        return "".concat(this.getConfigKey(user), ".user_id");
    };
    CacheStore.prototype.getConfigFetchDateKey = function (user) {
        return "".concat(this.getConfigKey(user), ".fetch_date");
    };
    CacheStore.prototype.loadConfigUserId = function (user) {
        var userIdKey = this.getConfigUserIdKey(user);
        return this.load(userIdKey);
    };
    CacheStore.prototype.loadConfigFetchDate = function (user) {
        var fetchDateKey = this.getConfigFetchDateKey(user);
        return parseInt(this.load(fetchDateKey) || '0', 10);
    };
    CacheStore.prototype.remove = function (storeKey) {
        var _a;
        (_a = this.store) === null || _a === void 0 ? void 0 : _a.removeItem(storeKey);
    };
    CacheStore.prototype.saveConfig = function (data, user) {
        var _a;
        var configKey = this.getConfigKey(user);
        var fetchDateKey = this.getConfigFetchDateKey(user);
        var userIdKey = this.getConfigUserIdKey(user);
        this.save(configKey, data);
        this.save(fetchDateKey, Date.now());
        this.save(userIdKey, user.user_id);
        (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info('Successfully saved config to local storage');
    };
    CacheStore.prototype.loadConfig = function (user, configCacheTTL) {
        if (configCacheTTL === void 0) { configCacheTTL = 604800000; }
        var userId = this.loadConfigUserId(user);
        var cachedFetchDate = this.loadConfigFetchDate(user);
        var isConfigCacheTTLExpired = Date.now() - cachedFetchDate > configCacheTTL;
        if (user.user_id === userId && !isConfigCacheTTLExpired) {
            var configKey = this.getConfigKey(user);
            return this.load(configKey);
        }
        return null;
    };
    CacheStore.prototype.saveUser = function (user) {
        var _a;
        if (!user) {
            throw new Error('No user to save');
        }
        this.save(exports.StoreKey.User, user);
        (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info('Successfully saved user to local storage');
    };
    CacheStore.prototype.loadUser = function () {
        return this.load(exports.StoreKey.User);
    };
    CacheStore.prototype.saveAnonUserId = function (userId) {
        var _a;
        this.save(exports.StoreKey.AnonUserId, userId);
        (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info('Successfully saved anonymous user id to local storage');
    };
    CacheStore.prototype.loadAnonUserId = function () {
        return this.load(exports.StoreKey.AnonUserId);
    };
    return CacheStore;
}());
exports.CacheStore = CacheStore;
exports.default = CacheStore;
//# sourceMappingURL=CacheStore.js.map